@@ -44,14 +44,7 @@ def wrapMainFunction(dagger_api, func, task_name=None, task_run_id=None):
                 kwargs=kwargs
             )
 
-            task_metadata = dict(
-                # logGroupName=context.log_group_name,
-                # logStreamName=context.log_stream_name,
-                region=os.getenv('AWS_REGION', None),
-                execution_env=os.getenv('AWS_EXECUTION_ENV', None)
-            )
-
-            task = api.createTask(
+            task = dagger_api.createTask(
                 task_name,
                 task_run_id,
                 task_input=task_input,
@@ -63,18 +56,14 @@ def wrapMainFunction(dagger_api, func, task_name=None, task_run_id=None):
 
         try:
             task_output = func(*args, **kwargs)
+            task.update(task_status='succeeded', task_output=task_output)
+            return task_output
         except Exception as e:
+            print('Task failed')
+            print(e)
             if task is not None:
                 task.update(task_status='failed', task_output=str(e))
 
-        try:
-            task.update(task_status='succeeded', task_output=task_output)
-        except Exception as e:
-            print('Failed to log dagger output')
-            print(e)
-
-        return task_output
-
     return _wrapper
 
 # {"function_version":"$LATEST","function_name":"complicated_job_rss","memoryLimitInMB":"512","logGroupName":"/aws/lambda/complicated_job_rss","logStreamName":"2020/05/24/[$LATEST]e47d9a855816499abffb1616ac6c1e9b","invokedFunctionArn":"arn:aws:lambda:us-east-2:985550760282:function:complicated_job_rss","awsRequestId":"00080e00-c853-469f-9ad8-57dca5c6c014"}
